#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=rifle1.21_base.ps
projection=-JM16.0c+
region=-R-108.5/-106.6/38.7/39.9
gmt psbasemap $region $projection -Bxa0.5f0.1 -Bya0.5f0.1 -BWeSn+t'Base Map rifle1.21' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    39.644  -107.400
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    38.880  -107.415
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    38.913  -107.402
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    38.898  -107.447
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    38.931  -107.387
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    38.927  -107.395
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    38.842  -107.470
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    38.870  -107.436
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    38.887  -107.454
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    38.904  -107.398
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    38.936  -107.477
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    38.878  -107.400
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    38.890  -107.415
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    38.929  -107.467
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    38.934  -107.453
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    38.913  -107.449
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    39.660  -107.470
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    38.907  -107.526
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    38.931  -107.557
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    38.952  -107.563
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    38.919  -107.555
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    38.943  -107.546
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    38.952  -107.497
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    38.922  -107.552
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    38.917  -107.538
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    38.955  -107.559
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    38.950  -107.555
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    38.998  -107.620
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    38.928  -107.539
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    38.914  -107.418
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    38.972  -107.587
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    38.910  -107.422
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    38.936  -107.544
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    38.914  -107.425
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    38.906  -107.426
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    38.954  -107.500
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    38.962  -107.447
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    38.942  -107.541
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    38.950  -107.503
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    38.933  -107.537
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    38.926  -107.552
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    38.942  -107.557
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    38.940  -107.556
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    38.940  -107.556
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    39.805  -107.366
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    39.155  -108.387
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    38.950  -107.561
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    38.936  -107.566
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    39.804  -107.372
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    38.954  -107.546
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    38.965  -107.574
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    39.743  -107.575
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    38.953  -107.467
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    38.948  -107.465
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    38.948  -107.488
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    39.537  -106.966
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    38.950  -107.493
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    38.946  -107.468
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    38.926  -107.549
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    38.971  -107.531
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    38.959  -107.468
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    38.910  -107.574
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    38.936  -107.613
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    38.939  -107.606
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    38.910  -107.646
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    38.934  -107.613
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    38.935  -107.616
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    38.858  -107.584
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    38.930  -107.608
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    38.948  -107.608
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    38.930  -107.560
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    38.933  -107.622
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    38.921  -107.578
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    39.208  -107.938
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    38.953  -107.484
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    39.240  -106.783
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    38.969  -107.463
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    38.977  -107.483
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    39.484  -108.226
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    38.956  -107.485
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    38.976  -107.496
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    39.603  -107.587
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    39.147  -107.249
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    39.109  -107.244
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    39.119  -107.247
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    39.606  -107.590
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    39.269  -108.228
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    39.751  -108.406
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    39.753  -108.401
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    39.765  -108.367
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    38.931  -107.423
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    39.609  -107.338
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    39.584  -107.364
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    39.645  -107.405
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    39.597  -107.378
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    39.546  -107.380
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    39.058  -107.028
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    39.070  -107.479
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    39.004  -107.445
END
gmt psxy -: -R $projection -Sl8p+t"100" -G0 -O -K << END >> $psfile
    39.369  -106.722
END
gmt psxy -: -R $projection -Sl8p+t"101" -G0 -O -K << END >> $psfile
    39.689  -107.486
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.644  -107.399
    39.644  -107.400
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.618  -107.343
    39.644  -107.400
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.882  -107.417
    38.880  -107.415
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.851  -107.384
    38.880  -107.415
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.919  -107.402
    38.913  -107.402
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.880  -107.394
    38.913  -107.402
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.892  -107.441
    38.898  -107.447
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.853  -107.386
    38.898  -107.447
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.932  -107.389
    38.931  -107.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.896  -107.420
    38.931  -107.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.927  -107.396
    38.927  -107.395
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.868  -107.394
    38.927  -107.395
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.842  -107.467
    38.842  -107.470
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.890  -107.445
    38.842  -107.470
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.869  -107.435
    38.870  -107.436
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.917  -107.440
    38.870  -107.436
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.887  -107.455
    38.887  -107.454
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.853  -107.358
    38.887  -107.454
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.903  -107.398
    38.904  -107.398
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.825  -107.425
    38.904  -107.398
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.936  -107.479
    38.936  -107.477
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.875  -107.497
    38.936  -107.477
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.878  -107.400
    38.878  -107.400
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.929  -107.409
    38.878  -107.400
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.891  -107.417
    38.890  -107.415
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.817  -107.325
    38.890  -107.415
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.930  -107.468
    38.929  -107.467
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.932  -107.489
    38.929  -107.467
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.934  -107.454
    38.934  -107.453
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.953  -107.527
    38.934  -107.453
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.913  -107.450
    38.913  -107.449
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.831  -107.415
    38.913  -107.449
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.660  -107.473
    39.660  -107.470
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.543  -107.421
    39.660  -107.470
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.907  -107.527
    38.907  -107.526
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.844  -107.435
    38.907  -107.526
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.926  -107.560
    38.931  -107.557
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.989  -107.562
    38.931  -107.557
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.949  -107.563
    38.952  -107.563
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.042  -107.532
    38.952  -107.563
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.920  -107.557
    38.919  -107.555
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.834  -107.572
    38.919  -107.555
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.946  -107.549
    38.943  -107.546
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.000  -107.503
    38.943  -107.546
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.951  -107.497
    38.952  -107.497
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.885  -107.458
    38.952  -107.497
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.922  -107.555
    38.922  -107.552
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.865  -107.524
    38.922  -107.552
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.914  -107.537
    38.917  -107.538
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.844  -107.421
    38.917  -107.538
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.956  -107.560
    38.955  -107.559
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.932  -107.536
    38.955  -107.559
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.952  -107.555
    38.950  -107.555
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.859  -107.490
    38.950  -107.555
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.998  -107.620
    38.998  -107.620
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.917  -107.634
    38.998  -107.620
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.930  -107.539
    38.928  -107.539
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.828  -107.517
    38.928  -107.539
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.916  -107.419
    38.914  -107.418
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.869  -107.384
    38.914  -107.418
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.972  -107.585
    38.972  -107.587
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.916  -107.558
    38.972  -107.587
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.910  -107.422
    38.910  -107.422
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.807  -107.206
    38.910  -107.422
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.937  -107.544
    38.936  -107.544
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.854  -107.447
    38.936  -107.544
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.914  -107.428
    38.914  -107.425
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.855  -107.315
    38.914  -107.425
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.906  -107.425
    38.906  -107.426
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.852  -107.312
    38.906  -107.426
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.954  -107.500
    38.954  -107.500
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.961  -107.467
    38.954  -107.500
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.962  -107.446
    38.962  -107.447
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.167  -107.393
    38.962  -107.447
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.943  -107.541
    38.942  -107.541
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.029  -107.642
    38.942  -107.541
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.951  -107.502
    38.950  -107.503
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.896  -107.454
    38.950  -107.503
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.933  -107.537
    38.933  -107.537
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.825  -107.475
    38.933  -107.537
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.926  -107.552
    38.926  -107.552
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.811  -107.682
    38.926  -107.552
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.943  -107.556
    38.942  -107.557
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.922  -107.564
    38.942  -107.557
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.941  -107.554
    38.940  -107.556
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.901  -107.546
    38.940  -107.556
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.942  -107.556
    38.940  -107.556
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.921  -107.439
    38.940  -107.556
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.805  -107.365
    39.805  -107.366
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.792  -107.224
    39.805  -107.366
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.154  -108.389
    39.155  -108.387
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.120  -108.366
    39.155  -108.387
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.951  -107.562
    38.950  -107.561
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.927  -107.555
    38.950  -107.561
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.938  -107.566
    38.936  -107.566
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.927  -107.555
    38.936  -107.566
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.806  -107.370
    39.804  -107.372
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.798  -107.438
    39.804  -107.372
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.954  -107.548
    38.954  -107.546
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.880  -107.382
    38.954  -107.546
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.966  -107.574
    38.965  -107.574
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.896  -107.584
    38.965  -107.574
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.728  -107.570
    39.743  -107.575
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.763  -107.528
    39.743  -107.575
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.953  -107.468
    38.953  -107.467
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.947  -107.497
    38.953  -107.467
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.941  -107.473
    38.948  -107.465
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.942  -107.467
    38.948  -107.465
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.947  -107.488
    38.948  -107.488
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.898  -107.523
    38.948  -107.488
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.529  -106.980
    39.537  -106.966
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.533  -106.984
    39.537  -106.966
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.954  -107.492
    38.950  -107.493
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.883  -107.478
    38.950  -107.493
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.946  -107.469
    38.946  -107.468
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.886  -107.504
    38.946  -107.468
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.919  -107.546
    38.926  -107.549
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.946  -107.552
    38.926  -107.549
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.971  -107.533
    38.971  -107.531
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.912  -107.435
    38.971  -107.531
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.960  -107.467
    38.959  -107.468
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.895  -107.342
    38.959  -107.468
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.910  -107.574
    38.910  -107.574
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.879  -107.591
    38.910  -107.574
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.936  -107.613
    38.936  -107.613
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.921  -107.649
    38.936  -107.613
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.939  -107.606
    38.939  -107.606
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.917  -107.656
    38.939  -107.606
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.909  -107.647
    38.910  -107.646
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.028  -107.636
    38.910  -107.646
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.934  -107.614
    38.934  -107.613
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.934  -107.671
    38.934  -107.613
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.935  -107.616
    38.935  -107.616
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.882  -107.632
    38.935  -107.616
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.860  -107.595
    38.858  -107.584
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.842  -107.616
    38.858  -107.584
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.930  -107.608
    38.930  -107.608
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.866  -107.539
    38.930  -107.608
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.947  -107.609
    38.948  -107.608
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.999  -107.552
    38.948  -107.608
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.929  -107.560
    38.930  -107.560
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.834  -107.511
    38.930  -107.560
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.935  -107.618
    38.933  -107.622
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.892  -107.588
    38.933  -107.622
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.922  -107.578
    38.921  -107.578
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.925  -107.510
    38.921  -107.578
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.208  -107.938
    39.208  -107.938
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.197  -107.915
    39.208  -107.938
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.953  -107.484
    38.953  -107.484
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.893  -107.476
    38.953  -107.484
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.242  -106.784
    39.240  -106.783
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.225  -106.764
    39.240  -106.783
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.969  -107.463
    38.969  -107.463
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.993  -107.437
    38.969  -107.463
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.976  -107.483
    38.977  -107.483
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.903  -107.507
    38.977  -107.483
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.486  -108.227
    39.484  -108.226
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.490  -108.231
    39.484  -108.226
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.956  -107.486
    38.956  -107.485
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.920  -107.488
    38.956  -107.485
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.976  -107.496
    38.976  -107.496
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.892  -107.472
    38.976  -107.496
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.603  -107.589
    39.603  -107.587
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.548  -107.567
    39.603  -107.587
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.147  -107.251
    39.147  -107.249
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.205  -107.279
    39.147  -107.249
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.109  -107.244
    39.109  -107.244
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.097  -107.253
    39.109  -107.244
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.120  -107.249
    39.119  -107.247
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.108  -107.252
    39.119  -107.247
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.606  -107.591
    39.606  -107.590
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.526  -107.562
    39.606  -107.590
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.268  -108.229
    39.269  -108.228
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.274  -108.228
    39.269  -108.228
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.752  -108.405
    39.751  -108.406
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.843  -108.337
    39.751  -108.406
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.757  -108.408
    39.753  -108.401
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.729  -108.427
    39.753  -108.401
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.764  -108.370
    39.765  -108.367
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.729  -108.426
    39.765  -108.367
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.934  -107.426
    38.931  -107.423
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.904  -107.406
    38.931  -107.423
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.612  -107.336
    39.609  -107.338
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.625  -107.343
    39.609  -107.338
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.585  -107.365
    39.584  -107.364
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.595  -107.358
    39.584  -107.364
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.647  -107.409
    39.645  -107.405
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.601  -107.354
    39.645  -107.405
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.596  -107.377
    39.597  -107.378
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.623  -107.383
    39.597  -107.378
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.544  -107.378
    39.546  -107.380
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.574  -107.352
    39.546  -107.380
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.076  -107.014
    39.058  -107.028
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.976  -107.023
    39.058  -107.028
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.070  -107.482
    39.070  -107.479
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.966  -107.565
    39.070  -107.479
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.002  -107.445
    39.004  -107.445
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.887  -107.461
    39.004  -107.445
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.366  -106.724
    39.369  -106.722
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.286  -106.775
    39.369  -106.722
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    39.687  -107.485
    39.689  -107.486
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    39.630  -107.471
    39.689  -107.486
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    39.644  -107.400   -10.652     2.600     3.547
    38.880  -107.415    29.234     2.444     3.836
    38.913  -107.402     1.394     1.987     3.778
    38.898  -107.447   -23.758     3.171     5.613
    38.931  -107.387    -6.388     2.656     3.286
    38.927  -107.395    41.572     2.015     3.306
    38.842  -107.470    18.831     4.629     8.954
    38.870  -107.436   -11.611     2.434     3.248
    38.887  -107.454   -22.658     2.208     3.909
    38.904  -107.398    20.696     2.603     3.236
    38.936  -107.477   -85.219     1.757     1.907
    38.878  -107.400   -53.910     7.385     8.926
    38.890  -107.415    21.254     1.909     3.121
    38.929  -107.467   -32.616     1.974     2.406
    38.934  -107.453    25.557     2.530     3.421
    38.913  -107.449    42.678     2.419     4.706
    39.660  -107.470    50.687     2.521     2.844
    38.907  -107.526    47.847     1.886     3.426
    38.931  -107.557    72.056     2.101     4.338
    38.952  -107.563    76.967     2.327     3.374
    38.919  -107.555    49.968     2.032     3.029
    38.943  -107.546    72.548     2.479     5.090
    38.952  -107.497    42.754     1.743     2.780
    38.922  -107.552    44.604     2.292     4.479
    38.917  -107.538    45.739     2.068     2.759
    38.955  -107.559    49.143     1.957     3.990
    38.950  -107.555    44.033     1.757     3.668
    38.998  -107.620    52.851     2.347     3.123
    38.928  -107.539    44.357     1.424     3.423
    38.914  -107.418    41.784     2.616     4.132
    38.972  -107.587    61.626     2.185     3.254
    38.910  -107.422    -0.368     1.220     1.376
    38.936  -107.544    79.801     1.631     2.420
    38.914  -107.425    46.136     2.129     3.758
    38.906  -107.426    31.547     1.081     1.457
    38.954  -107.500   -68.948     0.826     0.865
    38.962  -107.447    40.149     4.275     4.981
    38.942  -107.541   -75.904     0.795     0.859
    38.950  -107.503   -70.765     0.834     0.956
    38.933  -107.537    81.026     0.710     0.783
    38.926  -107.552   -87.886     0.938     1.137
    38.942  -107.557    79.196     0.626     0.671
    38.940  -107.556    46.061     1.890     2.748
    38.940  -107.556    81.872     0.746     0.824
    39.805  -107.366    34.456     0.898     1.056
    39.155  -108.387   -13.867     2.311     4.870
    38.950  -107.561    78.670     2.647     5.191
    38.936  -107.566    53.897     2.843     5.194
    39.804  -107.372   -50.833     2.051     3.206
    38.954  -107.546    10.726     1.784     2.042
    38.965  -107.574    10.683     1.510     1.626
    39.743  -107.575    57.403     2.784     5.319
    38.953  -107.467    49.758     1.870     4.450
    38.948  -107.465   -70.977     1.925     2.154
    38.948  -107.488   -62.398     1.855     3.154
    39.537  -106.966   -74.029     2.075     2.819
    38.950  -107.493   -89.902     1.267     1.971
    38.946  -107.468    71.517     1.544     2.387
    38.926  -107.549    59.616     2.828     8.042
    38.971  -107.531   -65.663     2.856     4.560
    38.959  -107.468   -49.128     2.105     3.083
    38.910  -107.574    52.358     1.526     2.444
    38.936  -107.613    37.494     2.788     4.964
    38.939  -107.606    75.060     1.233     1.740
    38.910  -107.646    63.455     2.754     6.359
    38.934  -107.613    74.379     1.021     1.944
    38.935  -107.616    53.802     1.539     3.511
    38.858  -107.584    58.246     2.150     3.009
    38.930  -107.608   -87.939     1.286     1.994
    38.948  -107.608   -30.113     1.771     2.047
    38.930  -107.560   -10.801     2.752     3.382
    38.933  -107.622   -71.037     1.612     1.688
    38.921  -107.578   -55.083     2.523     2.923
    39.208  -107.938    47.178     3.908     6.258
    38.953  -107.484    78.512     1.257     1.999
    39.240  -106.783    53.178     3.165     5.201
    38.969  -107.463    79.670     3.425     7.631
    38.977  -107.483    73.246     1.137     2.010
    39.484  -108.226   -80.131     3.204     5.273
    38.956  -107.485    81.949     1.627     2.319
    38.976  -107.496    88.755     1.168     1.567
    39.603  -107.587    56.226     2.170     2.885
    39.147  -107.249    83.236     2.879     3.967
    39.109  -107.244    77.245     1.327     2.263
    39.119  -107.247   -88.295     1.829     3.107
    39.606  -107.590   -55.584     1.761     2.053
    39.269  -108.228    14.223     2.418     3.402
    39.751  -108.406    21.779     2.356     2.609
    39.753  -108.401   -76.529     2.610     3.079
    39.765  -108.367    77.480     2.306     2.653
    38.931  -107.423    84.048     2.451     3.016
    39.609  -107.338    81.579     2.886     4.052
    39.584  -107.364   -49.599     1.914     2.839
    39.645  -107.405    53.286     2.948     3.770
    39.597  -107.378    55.652     3.076     3.551
    39.546  -107.380    49.452     2.946     3.942
    39.058  -107.028    71.921     3.014     6.088
    39.070  -107.479    13.655     5.152     7.975
    39.004  -107.445    58.023     3.108     4.911
    39.369  -106.722    79.563     5.002     6.452
    39.689  -107.486    80.526     4.187     5.346
END

# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    38.796  -108.439    65.978     1.136     1.327
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    38.796  -108.416   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    38.796  -108.439     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    38.796  -108.439     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    38.751  -108.439   5 km
END
